@@ -2,13 +2,11 @@
 
 set -ex
 
-# Resize root partition
-dnf install -y cloud-utils-growpart
-growpart /dev/vda 1
-xfs_growfs -d /
-
 cni_manifest="/tmp/cni.yaml"
 
+setenforce 0
+sed -i "s/^SELINUX=.*/SELINUX=permissive/" /etc/selinux/config
+
 # Disable swap
 swapoff -a
 sed -i '/ swap / s/^/#/' /etc/fstab
@@ -26,58 +24,41 @@ yum -y remove firewalld
 # Required for iscsi demo to work.
 yum -y install iscsi-initiator-utils
 
-# Install docker required packages.
-dnf -y install yum-utils \
-    device-mapper-persistent-data \
-    lvm2
-
-# Add Docker repository.
-dnf config-manager --add-repo=https://download.docker.com/linux/centos/docker-ce.repo
-
-# Install Docker CE.
-dnf install -y docker-ce --nobest
-
-# Create /etc/docker directory.
-mkdir /etc/docker
-
-# Setup docker daemon
-cat << EOF > /etc/docker/daemon.json
-{
-  "insecure-registries" : ["registry:5000"],
-  "log-driver": "json-file",
-  "exec-opts": ["native.cgroupdriver=systemd"],
-  "ipv6": true,
-  "fixed-cidr-v6": "2001:db8:1::/64",
-  "selinux-enabled": true
-}
-EOF
-
-mkdir -p /etc/systemd/system/docker.service.d
-
-# Restart Docker
-systemctl daemon-reload
-systemctl restart docker
-
-#TODO: el8 repo
-# Add Kubernetes repository.
 cat <<EOF >/etc/yum.repos.d/kubernetes.repo
 [kubernetes]
 name=Kubernetes
-baseurl=https://packages.cloud.google.com/yum/repos/kubernetes-el7-x86_64
+baseurl=http://yum.kubernetes.io/repos/kubernetes-el7-x86_64
 enabled=1
 gpgcheck=1
-repo_gpgcheck=0
-gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
+repo_gpgcheck=1
+gpgkey=https://packages.cloud.google.com/yum/doc/yum-key.gpg
+       https://packages.cloud.google.com/yum/doc/rpm-package-key.gpg
 EOF
+yum install -y \
+  docker-1.13.1 \
+  python-docker-py-1.10.6 \
+  python3-pip
 
-# Install Kubernetes packages.
-dnf install --nogpgcheck --disableexcludes=kubernetes -y \
+pip3 install --default-timeout=100 docker-pycreds
+
+# Log to json files instead of journald
+sed -i 's/--log-driver=journald //g' /etc/sysconfig/docker
+echo '{ "insecure-registries" : ["registry:5000"] }' > /etc/docker/daemon.json
+
+# Enable the permanent logging
+# Required by the fluentd journald plugin
+# The default settings in recent distribution for systemd is set to auto,
+# when on auto journal is permament when /var/log/journal exists
+mkdir -p /var/log/journal
+
+# Omit pgp checks until https://github.com/kubernetes/kubeadm/issues/643 is resolved.
+yum install --nogpgcheck -y \
     kubeadm-${version} \
     kubelet-${version} \
     kubectl-${version} \
-    kubernetes-cni
+    kubernetes-cni-0.6.0
 
-# TODO use config file! this is deprecated
+    # TODO use config file! this is deprecated
 cat <<EOT >/etc/sysconfig/kubelet
 KUBELET_EXTRA_ARGS=--cgroup-driver=systemd --runtime-cgroups=/systemd/system.slice --kubelet-cgroups=/systemd/system.slice --feature-gates="BlockVolume=true,CSIBlockVolume=true,VolumeSnapshotDataSource=true"
 EOT
@@ -101,77 +82,11 @@ sysctl --system
 echo bridge >> /etc/modules
 echo br_netfilter >> /etc/modules
 
-# configure additional settings for cni plugin
-cat <<EOF >/etc/NetworkManager/conf.d/001-calico.conf
-[keyfile]
-unmanaged-devices=interface-name:cali*;interface-name:tunl*
-EOF
-
-# Use dhclient to have expected hostname behaviour
-cat <<EOF >/etc/NetworkManager/conf.d/002-dhclient.conf
-[main]
-dhcp=dhclient
-EOF
-
-sysctl -w net.netfilter.nf_conntrack_max=1000000
-echo "net.netfilter.nf_conntrack_max=1000000" >> /etc/sysctl.conf
-
-systemctl restart NetworkManager
-
-mkdir -p /tmp/kubeadm-patches/
-
-cat >/tmp/kubeadm-patches/kustomization.yaml <<EOF
-patchesJson6902:
-- target:
-    version: v1
-    kind: Pod
-    name: kube-apiserver
-    namespace: kube-system
-  path: add-security-context.yaml
-- target:
-    version: v1
-    kind: Pod
-    name: kube-controller-manager
-    namespace: kube-system
-  path: add-security-context.yaml
-- target:
-    version: v1
-    kind: Pod
-    name: kube-scheduler
-    namespace: kube-system
-  path: add-security-context.yaml
-- target:
-    version: v1
-    kind: Pod
-    name: etcd
-    namespace: kube-system
-  path: add-security-context.yaml
-EOF
-
-cat >/tmp/kubeadm-patches/add-security-context.yaml <<EOF
-- op: add
-  path: /spec/securityContext
-  value:
-    seLinuxOptions:
-      type: spc_t
-EOF
-
-cat >/tmp/kubeadm-patches/add-security-context-deployment-patch.yaml <<EOF
-spec:
-  template:
-    spec:
-      securityContext:
-        seLinuxOptions:
-          type: spc_t
-EOF
-
-
 default_cidr="192.168.0.0/16"
 pod_cidr="10.244.0.0/16"
-kubeadm init --pod-network-cidr=$pod_cidr --kubernetes-version v${version} --token abcdef.1234567890123456 --experimental-kustomize /tmp/kubeadm-patches/
+kubeadm init --pod-network-cidr=$pod_cidr --kubernetes-version v${version} --token abcdef.1234567890123456
 
-kubectl --kubeconfig=/etc/kubernetes/admin.conf patch deployment coredns -n kube-system -p "$(cat /tmp/kubeadm-patches/add-security-context-deployment-patch.yaml)"
-sed -i -e "s?$default_cidr?$pod_cidr?g" $cni_manifest
+sed -i -e "s?$default_cidr?$pod_cidr?g" $cni_manifest 
 kubectl --kubeconfig=/etc/kubernetes/admin.conf create -f "$cni_manifest"
 
 # Wait at least for 7 pods
@@ -304,8 +219,3 @@ docker pull quay.io/k8scsi/csi-provisioner:v1.0.1
 docker pull quay.io/k8scsi/csi-snapshotter:v1.0.1
 docker pull quay.io/cephcsi/rbdplugin:v1.0.0
 docker pull quay.io/k8scsi/csi-node-driver-registrar:v1.0.2
-
-# Pre pull cluster network addons operator images and store manifests
-# so we can use them at cluster-up
-cp -rf /tmp/cnao/ /opt/
-for i in $(grep -A 2 "IMAGE" /opt/cnao/operator.yaml |grep value | awk '{print $2}'); do docker pull $i; done
